==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/mi/admin/statuslabels/message.php <==
<?php

return array(

    'does_not_exist' => 'Kaore te Ingoa Tūnga i te tīariari.',
    'assoc_assets'	 => 'Ko tenei Tapanga Whakaaetanga kei te hono atu ki tetahi rawa rawa, kaore e taea te muku. Whakaorangia nga taonga ki a koe kia kaua e tuhi i tenei tikanga ka ngana ano.',


    'create' => array(
        'error'   => 'Kaore i tuhia te Tapanga Whakaaetanga, me ngana ano.',
        'success' => 'I hanga angitu te Tapanga Whakaaetanga.'
    ),

    'update' => array(
        'error'   => 'Kāore i te whakahou te Tapanga Tūnga, tēnā whakamātau anō',
        'success' => 'Kua whakahoutia te Tapanga Whakaaetanga.'
    ),

    'delete' => array(
        'confirm'   => 'Kei te hiahia koe ki te muku i tenei Tapanga Tūnga?',
        'error'   => 'He raru kei te whakakore i te Tapanga Tūnga. Tena ngana ano.',
        'success' => 'I mukua te Tapanga Whakaaetanga.'
    ),

    'help' => array(
        'undeployable'   => 'Kaore e taea te tuku atu i enei taonga ki tetahi.',
        'deployable'   => 'Ka taea te tirotiro i enei taonga. Kia tohaina ratou, ka whakatauhia he tohu meta o <i class="fa fa-circle text-blue"></i> <strong>Deployed</strong>.',
        'archived'   => 'Kaore e taea te tirotiro i enei taonga, ka whakaaturia anake i roto i te tirohanga Whakamahia. He whai hua tenei mo te pupuri i nga korero e pa ana ki nga moni mo te tahua moni / kaupapa whakamaharatanga, engari ko te tiaki ia ratou i te rarangi o nga raanei raanei.',
        'pending'   => 'Kaore e taea te tuku atu i enei taonga ki tetahi, e whakamahia ana mo nga mea e tika ana mo te whakapai, engari e tika ana kia hoki mai ki te rere.',
    ),

);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/mi/admin/statuslabels/message.php <==
<?php

return [

    'does_not_exist' => 'Kaore te Ingoa Tūnga i te tīariari.',
    'assoc_assets'	 => 'Ko tenei Tapanga Whakaaetanga kei te hono atu ki tetahi rawa rawa, kaore e taea te muku. Whakaorangia nga taonga ki a koe kia kaua e tuhi i tenei tikanga ka ngana ano.',

    'create' => [
        'error'   => 'Kaore i tuhia te Tapanga Whakaaetanga, me ngana ano.',
        'success' => 'I hanga angitu te Tapanga Whakaaetanga.',
    ],

    'update' => [
        'error'   => 'Kāore i te whakahou te Tapanga Tūnga, tēnā whakamātau anō',
        'success' => 'Kua whakahoutia te Tapanga Whakaaetanga.',
    ],

    'delete' => [
        'confirm'   => 'Kei te hiahia koe ki te muku i tenei Tapanga Tūnga?',
        'error'   => 'He raru kei te whakakore i te Tapanga Tūnga. Tena ngana ano.',
        'success' => 'I mukua te Tapanga Whakaaetanga.',
    ],

    'help' => [
        'undeployable'   => 'Kaore e taea te tuku atu i enei taonga ki tetahi.',
        'deployable'   => 'These assets can be checked out. Once they are assigned, they will assume a meta status of <i class="fas fa-circle text-blue"></i> <strong>Deployed</strong>.',
        'archived'   => 'Kaore e taea te tirotiro i enei taonga, ka whakaaturia anake i roto i te tirohanga Whakamahia. He whai hua tenei mo te pupuri i nga korero e pa ana ki nga moni mo te tahua moni / kaupapa whakamaharatanga, engari ko te tiaki ia ratou i te rarangi o nga raanei raanei.',
        'pending'   => 'Kaore e taea te tuku atu i enei taonga ki tetahi, e whakamahia ana mo nga mea e tika ana mo te whakapai, engari e tika ana kia hoki mai ki te rere.',
    ],

];
